@@ -131,10 +131,10 @@ class work_sheet_tool():
             return vals[0]
         return val
 
-    def exec_task(self, target, pos_mapping: collections.defaultdict):
+    def exec_task(self, target, pos_mapping: collections.defaultdict, pos: collections.defaultdict):
         while self.task_queue:
             func, coordinate = self.task_queue.popleft()
-            self.dynamic_method(func, coordinate, target, pos_mapping)
+            self.dynamic_method(func, coordinate, target, pos_mapping, pos)
 
     def replace_pos(self, start: int, col: int, pos: list):
         n = start
@@ -165,6 +165,8 @@ class work_sheet_tool():
                     if pos[i][j] == 0:
                         self.replace_pos(i, j, pos)
                     if j not in pos_mapping[i]:
+                        if i == 5 and j == 2:
+                            print(1)
                         pos_mapping[i].setdefault(j, []).append(
                             pos_mapping[i - 1][j][-1] + 1 if i - 1 > 0 else i
                         )
@@ -222,12 +224,15 @@ class work_sheet_tool():
                     source_cell: [Cell, MergedCell] = pos[i][j]
                     target_cell: Cell = target.cell(i + 1, j + 1)
                     self.copy_cell(source_cell, target_cell)
-        for cell in source.merged_cells:
+        for i, cell in enumerate(source.merged_cells):
+            print(cell)
             cell_min_num = pos_mapping[cell.min_row - 1][cell.min_col - 1][0] + 1
             cell_max_num = pos_mapping[cell.max_row - 1][cell.max_col - 1][0] + 1
             target.merge_cells(start_row=cell_min_num, start_column=cell.min_col,
                             end_column=cell.max_col, end_row=cell_max_num)
-        self.exec_task(target, pos_mapping)
+            if i > 3:
+                print(1)
+        self.exec_task(target, pos_mapping, pos)
         self.write_table(source, target, pos_mapping)
         self.write_attr(source, target, pos_mapping)
 
